@@ -65,8 +65,9 @@ class Tatu(Storage):
         return self._config
 
     def __init__(self, url="sqlite://tatu-sqlite", threaded=True, alias=None, close_when_idle=False,
-                 disable_close=False):
+                 disable_close=False, force_lazyfetch=False):
         self.disable_close = disable_close
+        self.force_lazyfetch = force_lazyfetch
         self._config = locals().copy()
         del self._config["self"]
         if "__class__" in self._config:
@@ -97,8 +98,8 @@ class Tatu(Storage):
         return self.storage.uuid
 
     # TODO make all args/kwargs explicity for better docs/IDE integration
-    def fetch(self, data, lock=False, lazy=True):
-        return self.storage.fetch(data, lock, lazy)
+    def fetch(self, data, lock=False, lazy=True, ignorelock=False):
+        return self.storage.fetch(data, lock, self.force_lazyfetch or lazy, ignorelock)
 
     def store(self, data, unlock=False, ignoredup=False, lazy=False):
         return self.storage.store(data, unlock, ignoredup, lazy)
@@ -110,7 +111,7 @@ class Tatu(Storage):
         return self.storage.fetchstep(id)
 
     def fetchstream(self, id, lazy=True):
-        return self.storage.fetchstream(id, lazy)
+        return self.storage.fetchstream(id, self.force_lazyfetch or lazy)
 
     def hasdata(self, id, include_empty=False):
         return self.storage.hasdata(id, include_empty)
